@@ -39,7 +39,7 @@ use SNMP::Info::Layer2;
 
 our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.70';
+$VERSION = '3.81';
 
 %MIBS = (
     %SNMP::Info::Layer2::MIBS,
@@ -53,9 +53,9 @@ $VERSION = '3.70';
 
 %GLOBALS = (
     %SNMP::Info::Layer2::GLOBALS,
-    'os_ver' => 'ntwsVersionString',
-    'serial' => 'ntwsSerialNumber',
-    'mac'    => 'dot1dBaseBridgeAddress',
+    'os_ver'     => 'ntwsVersionString',
+    'nws_serial' => 'ntwsSerialNumber',
+    'mac'        => 'dot1dBaseBridgeAddress',
 );
 
 %FUNCS = (
@@ -139,6 +139,14 @@ sub vendor {
     return 'avaya';
 }
 
+sub serial {
+    my $nwss2300 = shift;
+    my $ser = $nwss2300->ntwsSerialNumber();
+#    my $ser = $nwss2300->nws_serial();
+
+    return $ser;
+}
+
 sub model {
     my $nwss2300 = shift;
     my $id = $nwss2300->id();
@@ -654,7 +662,7 @@ sub e_serial {
     my %e_serial;
 
     # Chassis
-    $e_serial{1} = $nwss2300->serial();
+    $e_serial{1} = $nwss2300->serial()  || '';
 
     # APs
     foreach my $iid ( keys %$ap_serial ) {
