@@ -30,19 +30,25 @@
 package SNMP::Info::Layer3::Fortinet;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
+use SNMP::Info::Aggregate 'agg_ports_ifstack';
 
-@SNMP::Info::Layer3::Fortinet::ISA
-    = qw/SNMP::Info::Layer3 Exporter/;
+@SNMP::Info::Layer3::Fortinet::ISA = qw/
+    SNMP::Info::Layer3
+    SNMP::Info::Aggregate
+    Exporter
+/;
 @SNMP::Info::Layer3::Fortinet::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
+our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.81';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
+    %SNMP::Info::Aggregate::MIBS,
     'FORTINET-CORE-MIB'      => 'fnSysSerial',
     'FORTINET-FORTIGATE-MIB' => 'fgVdMaxVdoms',
 );
@@ -63,6 +69,29 @@ sub vendor {
     return 'fortinet';
 }
 
+# fortios 5.4 and higher can have empty ifDescr. use ifName (but
+# without the ifAlias fixup that's done in layer3::i_name()) which
+# mimics fortios >5.4
+# copied from an old Layer3.pm which did not have duplicate
+# description fixup
+sub interfaces {
+    my $fortinet = shift;
+    my $partial  = shift;
+
+    my $interfaces   = $fortinet->i_index($partial);
+    my $descriptions = $fortinet->orig_i_name($partial);
+
+    my %interfaces = ();
+    foreach my $iid ( keys %$interfaces ) {
+        my $desc = $descriptions->{$iid};
+        next unless defined $desc;
+
+        $interfaces{$iid} = $desc;
+    }
+
+    return \%interfaces;
+}
+
 sub model {
     my $fortinet = shift;
     my $id = $fortinet->id() || '';
@@ -81,22 +110,24 @@ sub os {
 
 sub os_ver {
     my $fortinet = shift;
-    
+
     my $ver = $fortinet->fgSysVersion() || '';
 
     if ( $ver =~ /(\d+[\.\d]+)/ ) {
         return $1;
     }
-    
+
     return $ver;
 }
 
 sub serial {
     my $fortinet = shift;
-    
+
     return $fortinet->fnSysSerial();
 }
 
+sub agg_ports { return agg_ports_ifstack(@_) }
+
 1;
 __END__
 
@@ -110,14 +141,14 @@ Eric Miller
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $fortinet = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class = $fortinet->class();
@@ -127,17 +158,14 @@ Eric Miller
 
 Abstraction subclass for Fortinet network devices.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above. 
-
- my $fortinet = new SNMP::Info::Layer3::Fortinet(...);
-
 =head2 Inherited Classes
 
 =over
 
 =item SNMP::Info::Layer3
 
+=item SNMP::Info::Aggregate
+
 =back
 
 =head2 Required MIBs
@@ -152,6 +180,8 @@ after determining a more specific class using the method above.
 
 See L<SNMP::Info::Layer3/"Required MIBs"> for its own MIB requirements.
 
+See L<SNMP::Info::Aggregate/"Required MIBs"> for its own MIB requirements.
+
 =back
 
 =head1 GLOBALS
@@ -193,6 +223,20 @@ See documentation in L<SNMP::Info::Layer3/"GLOBALS"> for details.
 These are methods that return tables of information in the form of a reference
 to a hash.
 
+=over
+
+=item $fortinet->interfaces();
+
+Returns the map between SNMP Interface Identifier (iid) and C<ifName>.
+
+=item C<agg_ports>
+
+Returns a HASH reference mapping from slave to master port for each member of
+a port bundle on the device. Keys are ifIndex of the slave ports, Values are
+ifIndex of the corresponding master ports.
+
+=back
+
 =head2 Table Methods imported from SNMP::Info::Layer3
 
 See documentation in L<SNMP::Info::Layer3/"TABLE METHODS"> for details.
